==> open-cluster-management-apps-model-5.12.1-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorssubscription/apps/helmrelease/v1/GitBuilder.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class GitBuilder extends io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.GitFluentImpl<io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.GitBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.Git,io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.GitBuilder>{
  public GitBuilder() {
    this(false);
  }
  public GitBuilder(java.lang.Boolean validationEnabled) {
    this(new Git(), validationEnabled);
  }
  public GitBuilder(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.GitFluent<?> fluent) {
    this(fluent, false);
  }
  public GitBuilder(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.GitFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Git(), validationEnabled);
  }
  public GitBuilder(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.GitFluent<?> fluent,io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.Git instance) {
    this(fluent, instance, false);
  }
  public GitBuilder(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.GitFluent<?> fluent,io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.Git instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withBranch(instance.getBranch()); 
    fluent.withChartPath(instance.getChartPath()); 
    fluent.withUrls(instance.getUrls()); 
    this.validationEnabled = validationEnabled; 
  }
  public GitBuilder(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.Git instance) {
    this(instance,false);
  }
  public GitBuilder(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.Git instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withBranch(instance.getBranch()); 
    this.withChartPath(instance.getChartPath()); 
    this.withUrls(instance.getUrls()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.GitFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.Git build() {
    Git buildable = new Git(fluent.getBranch(),fluent.getChartPath(),fluent.getUrls());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    GitBuilder that = (GitBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> open-cluster-management-apps-model-6.1.0-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorssubscription/apps/helmrelease/v1/GitBuilder.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class GitBuilder extends GitFluentImpl<GitBuilder> implements VisitableBuilder<Git,GitBuilder>{
  public GitBuilder() {
    this(false);
  }
  public GitBuilder(Boolean validationEnabled) {
    this(new Git(), validationEnabled);
  }
  public GitBuilder(GitFluent<?> fluent) {
    this(fluent, false);
  }
  public GitBuilder(GitFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Git(), validationEnabled);
  }
  public GitBuilder(GitFluent<?> fluent,Git instance) {
    this(fluent, instance, false);
  }
  public GitBuilder(GitFluent<?> fluent,Git instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withBranch(instance.getBranch()); 
    fluent.withChartPath(instance.getChartPath()); 
    fluent.withUrls(instance.getUrls()); 
    this.validationEnabled = validationEnabled; 
  }
  public GitBuilder(Git instance) {
    this(instance,false);
  }
  public GitBuilder(Git instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withBranch(instance.getBranch()); 
    this.withChartPath(instance.getChartPath()); 
    this.withUrls(instance.getUrls()); 
    this.validationEnabled = validationEnabled; 
  }
  GitFluent<?> fluent;
  Boolean validationEnabled;
  public Git build() {
    Git buildable = new Git(fluent.getBranch(),fluent.getChartPath(),fluent.getUrls());
    return buildable;
  }
  
}
